SystemOrganization addCategory: #'AL-Tests-Json'!

TestCase subclass: #ALJsonParserTest
	instanceVariableNames: 'expect'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Json'!

!ALJsonParserTest methodsFor: 'emulating' stamp: 'cwp 10/13/2011 16:52'!
array: aBlock 
	| m tmp |
	m := self messages removeFirst.
	self assert: m selector = #array:.
	self assert: m arguments size = 1.
	self assert: (m argument isKindOf: BlockClosure).
	
	tmp := self messages.
	m argument value.
	aBlock value.
	self assert: self messages isEmpty.
	self messages: tmp.! !

!ALJsonParserTest methodsFor: 'running' stamp: 'cwp 4/2/2012 22:04'!
expect: expectBlock during: callbackBlock
	| tmp |
	tmp := self messages.
	self messages: OrderedCollection new.
	expectBlock value.
	callbackBlock value.
	self assert: self messages isEmpty.
	self messages: tmp.! !

!ALJsonParserTest methodsFor: 'accessing' stamp: 'cwp 10/13/2011 16:51'!
messages
	^ expect privAccumulator  ! !

!ALJsonParserTest methodsFor: 'accessing' stamp: 'cwp 10/13/2011 16:51'!
messages: anObject
	expect privAccumulator: anObject! !

!ALJsonParserTest methodsFor: 'emulating' stamp: 'cwp 4/1/2012 19:18'!
name: aString array: aBlock
	| m |
	m := self messages removeFirst.
	self assert: m selector = #name:array:.
	self assert: m arguments size = 2.
	self assert: (m arguments first isKindOf: String).
	self assert: (m arguments second isKindOf: BlockClosure).
	self expect: m arguments second during: aBlock
! !

!ALJsonParserTest methodsFor: 'emulating' stamp: 'cwp 4/1/2012 19:18'!
name: aString object: aBlock 
	| m |
	m := self messages removeFirst.
	self assert: m selector = #name:object:.
	self assert: m arguments size = 2.
	self assert: (m arguments first isKindOf: String).
	self assert: (m arguments second isKindOf: BlockClosure).
	self expect: m arguments second during: aBlock! !

!ALJsonParserTest methodsFor: 'emulating' stamp: 'cwp 4/1/2012 19:00'!
name: aString value: anObject
	| m |
	m := self messages removeFirst. 
	self assert: m selector = #name:value:.
	self assert: m arguments size = 2.
	self assert: m arguments first = aString.
	self assert: m arguments second = anObject.! !

!ALJsonParserTest methodsFor: 'emulating' stamp: 'cwp 4/1/2012 19:17'!
object: aBlock 
	| m |
	m := self messages removeFirst.
	self assert: m selector = #object:.
	self assert: m arguments size = 1.
	self assert: (m argument isKindOf: BlockClosure).
	self expect: m argument during: aBlock.
	
! !

!ALJsonParserTest methodsFor: 'running' stamp: 'cwp 10/13/2011 16:50'!
parse: aString
	| stream |
	stream := aString reading.
	ALJsonParser parse: stream for: self.
	self assert: self messages isEmpty.
	self should: [stream get] raise: Incomplete.! !

!ALJsonParserTest methodsFor: 'running' stamp: 'cwp 10/13/2011 16:50'!
setUp
	expect := MessageCatcher new.
	self messages: OrderedCollection new.
! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 15:29'!
testArrayAbc
	expect array: [expect value: 'abc'].
	self parse: '["abc"]'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 17:09'!
testArrayAbc123
	expect array: 
		[expect value: 'abc'.
		expect value: 123].
	self parse: '["abc",123]'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 17:19'!
testArrayAbc123Def
	expect array: 
		[expect value: 'abc'.
		expect value: 123.
		expect value: 'def'].
	self parse: '["abc",123,"def"]'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 15:30'!
testArrayEmpty
	expect array: [].
	self parse: '[]'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 4/1/2012 18:32'!
testArrayInObject
	expect object: 
		[expect name: 'a' array:
			[expect value: 42]].
	self parse: '{ "a":[42]}'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 00:15'!
testArrayWhitespace
	expect array: 
		[expect value: 'abc'.
		expect value: 'def'].
	self parse: '[ "abc" , "def" ]'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:27'!
testErrorArrayComma
	expect array: 
		[expect value: 42].
	self 
		should: [self parse: '[42 "foo"]']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:28'!
testErrorEscape
	self 
		should: [self parse: '"a\gc"']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:25'!
testErrorFalse
	self 
		should: [self parse: 'falls']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:35'!
testErrorNegativeNumber
	self 
		should: [self parse: '-1.x']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:21'!
testErrorNoColon
	expect object: [].
	self 
		should: [self parse: '{"name" "value"}']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:25'!
testErrorNull
	self 
		should: [self parse: 'nuul']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:36'!
testErrorNumber
	self 
		should: [self parse: '1.x']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:39'!
testErrorObjectComma
	expect object:
		[expect name: 'a' value: 42].
	self 
		should: [self parse: '{"a": 42 "string"}']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:24'!
testErrorTrue
	self 
		should: [self parse: 'trve']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 22:41'!
testErrorUnquotedString
	self 
		should: [self parse: 'plonk']
		raise: ALParseError.! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/11/2011 23:54'!
testFalse
	expect value: false.
	self parse: 'false'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/11/2011 23:47'!
testNull
	expect value: nil.
	self parse: 'null'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 15:31'!
testNumber123
	expect value: 123.
	self parse: '123'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 15:25'!
testNumber12Point3
	expect value: 12.3s1.
	self parse: '12.3'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 15:30'!
testNumberMinus123
	expect value: -123.0s1.
	self parse: '-123'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 15:31'!
testNumberMinus12Point3
	expect value: -12.3s1.
	self parse: '-12.3'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 00:04'!
testObjectA42
	expect object: 
		[expect name: 'a' value: 42].
	self parse: '{"a":42}'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 00:06'!
testObjectA42B96
	expect object: 
		[expect name: 'a' value: 42.
		expect name: 'b' value: 96].
	self parse: '{"a":42,"b":96}'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/13/2011 18:39'!
testObjectEmpty
	expect object: [].
	self parse: '{}'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 4/1/2012 18:44'!
testObjectInArray
	expect array: [expect object: [expect name: 'a' value: 42]].
	self parse: '[{"a":42}]'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 4/1/2012 09:35'!
testObjectInObject
	expect object: 
		[expect name: 'a' object:
			[expect name: 'b' value: 42]].
	self parse: '{ "a":{"b":42}}'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/14/2011 00:25'!
testObjectWhitespace
	expect object: 
		[expect name: 'a' value: 42.
		expect name: 'b' value: 96].
	self parse: '{ "a"  :   42    ,     "b" : 96 }'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:01'!
testStringAbc
	expect value: 'abc'.
	self parse: '"abc"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:25'!
testStringBackspace
	expect value: Character backspace asString.
	self parse: '"\b"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:28'!
testStringCarriageReturn
	expect value: Character cr asString.
	self parse: '"\r"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:01'!
testStringEmpty
	expect value: ''.
	self parse: '""'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:26'!
testStringFormfeed
	expect value: Character newPage asString.
	self parse: '"\f"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:35'!
testStringHexChar
	expect value: 'a'.
	self parse: '"\u0097"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:27'!
testStringNewline
	expect value: Character linefeed asString.
	self parse: '"\n"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:16'!
testStringQuote
	expect value: 'a"c'.
	self parse: '"a\"c"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:17'!
testStringReverseSolidus
	expect value: 'a\c'.
	self parse: '"a\\c"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:18'!
testStringSolidus
	expect value: 'a/c'.
	self parse: '"a\/c"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/12/2011 00:29'!
testStringTab
	expect value: Character tab asString.
	self parse: '"\t"'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 10/11/2011 23:48'!
testTrue
	expect value: true.
	self parse: 'true'! !

!ALJsonParserTest methodsFor: 'tests' stamp: 'cwp 4/1/2012 18:46'!
testTwoObjectsInArray
	expect array: 
		[expect object: [expect name: 'a' value: 42].
		expect object: [expect name: 'b' value: 43]].
	self parse: '[{"a":42},{"b":43}]'! !

!ALJsonParserTest methodsFor: 'emulating' stamp: 'cwp 10/13/2011 16:50'!
value: anObject
	| m |
	m := self messages removeFirst. 
	self assert: m selector = #value:.
	self assert: m arguments size = 1.
	self assert: m arguments first = anObject.! !

TestCase subclass: #ALJsonRenderingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Json'!

!ALJsonRenderingTest methodsFor: 'support' stamp: 'cwp 8/5/2011 23:19'!
assert: aString hasHashAt: anInteger

	anInteger 
		to: anInteger + 38 
		do: 
			[:index || char |
			char := aString at: index.
			self assert: ('0123456789abcedf' includes: char)]
	
! !

!ALJsonRenderingTest methodsFor: 'callbacks' stamp: 'cwp 8/22/2011 22:47'!
callback
	^ []! !

!ALJsonRenderingTest methodsFor: 'support' stamp: 'cwp 10/14/2012 02:12'!
expect: aString from: aBlock
	| compare context json locator stream |
	compare := aString reading.
	stream := 	[:actual || expected |
				expected := compare get.
				self assert: actual = expected] 
					writing.
	locator := ALRestfulLocator sequential.
	context := ALRenderingContext resource: self locator: locator.
	json := ALJsonRenderer context: context stream: stream.
	aBlock value: json.
	self should: [compare get] raise: Incomplete.! !

!ALJsonRenderingTest methodsFor: 'support' stamp: 'cwp 10/14/2012 02:12'!
render: renderBlock into: inspectionBlock
	| context json locator stream |
	stream := String new writing.
	locator := ALRestfulLocator sequential.
	context := ALRenderingContext resource: self locator: locator.
	json := ALJsonRenderer context: context stream: stream.
	renderBlock value: json.
	inspectionBlock value: stream conclusion.! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 7/21/2011 00:04'!
testArray
	self expect: '["griffle","plonk"]' from: 
		[ :json | 
		json array: 
			[json value: 'griffle'.
			json value: 'plonk']]! !

!ALJsonRenderingTest methodsFor: 'callbacks' stamp: 'cwp 10/14/2012 01:00'!
testCallback
	self 
		expect: '{"plonk":"/0"}' 
		from: [:json | json object: [json name: 'plonk' callback: self callback]]! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 7/21/2011 00:17'!
testNameArray
	self expect: '{"a":[42]}' from: 
		[:json | 
		json object:
			[json name: 'a' array:
				[json value: 42]]]! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 7/21/2011 10:53'!
testNameArrayDo
	self expect: '{"a":[1,2,3]}' from: 
		[:json | 
		json object:
			[json name: 'a' array: #(1 2 3) do: 
				[:i | json value: i]]]
				! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 1/25/2013 23:49'!
testNameComponent
		
	self
		expect: '{"a":"/0"}'
		from: [:json | json object: [json name: 'a' component: self]]
		! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 7/21/2011 00:16'!
testNameObject
	self expect: '{"child":{"a":42}}' from: 
		[:json | 
		json object: 
			[json name: 'child' object: 
				[json name: 'a' value: 42]]]! !

!ALJsonRenderingTest methodsFor: 'callbacks' stamp: 'cwp 3/4/2012 12:37'!
testNavigate
	self 
		expect: '{"plonk":"/0"}' 
		from: [:json | json object: [json name: 'plonk' navigate: self callback]]! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 7/21/2011 00:15'!
testNestedArrays
	self expect: '[1,[2,3]]' from: 
		[:json | 
		json array: 
			[json value: 1.
			json array: 
				[json value: 2.
				json value: 3]]]! !

!ALJsonRenderingTest methodsFor: 'basic json' stamp: 'cwp 7/21/2011 00:05'!
testObject
	self expect: '{"qi":"gong"}' from: 
		[ :json | 
		json object: 
			[ json name: 'qi' value: 'gong' ] ]! !

TestCase subclass: #ALSimpleJsonModelTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Json'!

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:20'!
assert: aString yields: expected
	| actual |
	actual := ALSimpleJsonModel parse: aString. 
	self assert: expected = actual! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:25'!
testArrayAbc
	self assert: '["abc"]' yields: #('abc')! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:25'!
testArrayAbc123
	self assert: '["abc",123]' yields: #('abc' 123)! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:27'!
testArrayAbc123Def
	self assert: '{ "a":[42]}' yields: (Dictionary with: 'a' -> #(42))! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:18'!
testArrayEmpty
	self assert: '[]' yields: Array new.! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:23'!
testFalse
	self assert: 'false' yields: false! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:24'!
testNull
	self assert: 'null' yields: nil! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:28'!
testNumber123
	self assert: '123' yields: 123! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:29'!
testNumber12Point3
	self assert: '12.3' yields: 12.3s1! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:29'!
testNumberMinus123
	self assert: '-123' yields: -123! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:29'!
testNumberMinus12Point3
	self assert: '-12.3' yields: -12.3s1.! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:31'!
testObjectA42
	self assert: '{"a":42}' yields: (Dictionary with: 'a'->42)! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:31'!
testObjectA42B96
	self assert: '{"a":42,"b":96}' yields: (Dictionary with: 'a'->42 with: 'b'->96)! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:32'!
testObjectEmpty
	self assert: '{}' yields: Dictionary new! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/10/2014 00:02'!
testObjectInArray
	self assert: '[{"a":42}]' yields: {Dictionary with: 'a'->42}! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/10/2014 00:04'!
testObjectInObject
	self assert: '{ "a":{"b":42}}' yields: (Dictionary with: 'a'->(Dictionary with: 'b'->42))! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/10/2014 00:05'!
testStringAbc
	self assert: '"abc"' yields: 'abc'! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/9/2014 23:24'!
testTrue
	self assert: 'true' yields: true! !

!ALSimpleJsonModelTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/10/2014 00:06'!
testTwoObjectsInArray
	self assert: '[{"a":42},{"b":43}]' yields: 
		{Dictionary with: 'a'->42.
		Dictionary with: 'b'->43}! !
